import { NextResponse } from 'next/server';
import type { NextRequest } from 'next/server';
import { isTokenValid } from './lib/auth';

// Paths that require authentication
const protectedPaths = [
  '/dashboard',
  '/dashboard/students',
  '/dashboard/sessions',
  '/dashboard/parents-evening',
];

export function middleware(request: NextRequest) {
  const { pathname } = request.nextUrl;
  
  // Check if the path is protected
  const isProtectedPath = protectedPaths.some(path => 
    pathname === path || pathname.startsWith(`${path}/`)
  );
  
  if (isProtectedPath) {
    // Get the token from cookies
    const token = request.cookies.get('auth-token')?.value;
    
    // If no token or invalid token, redirect to login
    if (!token || !isTokenValid(token)) {
      const url = new URL('/login', request.url);
      url.searchParams.set('from', pathname);
      return NextResponse.redirect(url);
    }
  }
  
  return NextResponse.next();
}

export const config = {
  matcher: [
    '/dashboard/:path*',
  ],
};